---
name: Request a new use case
about: Support for new SQL syntaxes, database capabilities, DBAPIs and DBAPI features
title: ''
labels: requires triage,use case
assignees: ''

---

**Describe the use case**
<!-- A clear and concise description of what the SQL or database capability is. -->

**Databases / Backends / Drivers targeted**

<!-- what database(s) is this for?  What drivers? -->

**Example Use**
<!-- provide a clear example of what the SQL looks like, or what the DBAPI code looks like -->


**Additional context**
<!-- Add any other context about the problem here. -->

**Have a nice day!**
